@@ -1,15 +1,15 @@
 // This simple list avoids a whole package
 var main = {
 Binary_Property : [
-'Alphabetic',
-'Any',
 'ASCII',
 'ASCII_Hex_Digit',
+'Alphabetic',
+'Any',
 'Assigned',
 'Bidi_Control',
 'Bidi_Mirrored',
-'Cased',
 'Case_Ignorable',
+'Cased',
 'Changes_When_Casefolded',
 'Changes_When_Casemapped',
 'Changes_When_Lowercased',
@@ -24,11 +24,13 @@ Binary_Property : [
 'Emoji',
 'Emoji_Component',
 'Emoji_Modifier',
-'Emoji_Presentation',    
+'Emoji_Modifier_Base',
+'Emoji_Presentation',
 'Expands_On_NFC',
 'Expands_On_NFD',
 'Expands_On_NFKC',
 'Expands_On_NFKD',
+'Extended_Pictographic',
 'Extender',
 'Full_Composition_Exclusion',
 'Grapheme_Base',
@@ -36,15 +38,21 @@ Binary_Property : [
 'Grapheme_Link',
 'Hex_Digit',
 'Hyphen',
-'ID_Continue',
-'Ideographic',
 'IDS_Binary_Operator',
-'ID_Start',
 'IDS_Trinary_Operator',
+'IDS_Unary_Operator',
+'ID_Compat_Math_Continue',
+'ID_Compat_Math_Start',
+'ID_Continue',
+'ID_Start',
+'Ideographic',
+'InCB',
 'Join_Control',
 'Logical_Order_Exception',
 'Lowercase',
 'Math',
+'Modifier_Combining_Mark',
+'NFKC_Simple_Casefold',
 'Noncharacter_Code_Point',
 'Other_Alphabetic',
 'Other_Default_Ignorable_Code_Point',
@@ -68,7 +76,7 @@ Binary_Property : [
 'Variation_Selector',
 'White_Space',
 'XID_Continue',
-'XID_Start',
+'XID_Start'
 ]
 };
 module.exports = main
